@@ -21,7 +21,6 @@
 #define CARD_H
 
 #include <gnome.h>
-#include "gdk-card-image.h"
 
 /*
  * Constants
@@ -55,15 +54,11 @@ GdkPixmap* get_slot_pixmap ( void );
 GdkPixmap* get_background_pixmap ( void );
 GdkPixmap* get_card_back_pixmap ( void );
 
-void load_pixmaps (GtkWidget*, GdkCardDeckOptions);
-void free_pixmaps (void);
+void set_card_size (gint width, gint height);
+void set_card_theme (gchar * theme);
 
-int get_card_width ( void );
-int get_card_height ( void );
-int get_horiz_offset ( void );
-int get_vert_offset ( void );
-int get_vert_start ( void );
-int get_horiz_start ( void );
+void load_pixmaps (void);
+void free_pixmaps (void);
 
 void add_card (GList**, hcard_type);
 #endif
