@@ -92,7 +92,6 @@ static gint gnome_modify_dice (GtkWidget *widget, GdkEventButton *event,
 static gint gnome_roll_dice (GtkWidget *widget, GdkEvent *event,
                              gpointer data);
 void update_score_state (void);
-static void undo_set_sensitive (gboolean state);
 static void roll_set_sensitive (gboolean state);
 static void UpdateRollLabel (void);
 
@@ -101,9 +100,26 @@ static void
 CheerWinner (void)
 {
         int winner;
+        int i;
+
+	ShowoffPlayer (ScoreList,CurrentPlayer,0);
 
         winner = FindWinner ();
-        if ( (winner<NumberOfHumans) && !IsCheater ) {
+
+        if (winner < 0) {
+                for (i = 0; i < NumberOfPlayers; i++) {
+                        if (total_score (i) == -winner) {
+                                ShowoffPlayer (ScoreList, i, 1);
+                        }
+                }
+                
+                say (_("The game is a draw!"));
+                return;
+        }
+
+	ShowoffPlayer (ScoreList,winner,1);
+
+        if (winner<NumberOfHumans) {
                 lastHighScore = gnome_score_log ((guint)WinningScore, 
                                                  NULL, TRUE);
 		update_score_state ();
@@ -111,9 +127,6 @@ CheerWinner (void)
                         ShowHighScores ();
         }
 
-	ShowoffPlayer (ScoreList,CurrentPlayer,0);
-	ShowoffPlayer (ScoreList,winner,1);
-
         if (players[winner].name)
                 say (ngettext("%s wins the game with %d point",
                               "%s wins the game with %d points", WinningScore),
@@ -122,7 +135,6 @@ CheerWinner (void)
 	else
                 say (_("Game over!"));
 
-        undo_set_sensitive (FALSE);
 }
 
 static gboolean
@@ -194,8 +206,6 @@ NextPlayer (void)
         SelectAllDice ();
         RollSelectedDice ();
 	
-	undo_set_sensitive (!players[CurrentPlayer].comp);
-
         if (players[CurrentPlayer].comp) {
                 if (DoDelay){
                         if (!last_timeout)
@@ -292,8 +302,6 @@ GyahtzeeNewGame (void)
 	for (i=0; i<NumberOfPlayers; i++)
                 ShowoffPlayer (ScoreList,i,0);
 	ShowoffPlayer (ScoreList,0,1);
-
-        undo_set_sensitive (FALSE);
 }
 
 
@@ -503,25 +511,10 @@ score_callback(GtkWidget *widget, gpointer data)
 	return FALSE;
 }
 
-static gint 
-undo_callback(GtkWidget *widget, gpointer data)
-{
-        int i;
-	if (!GameIsOver ()) {
-                for (i=0; i < NumberOfPlayers; i++)
-                        ExecSingleUndo (SCORE_OK);
-                say (_("Cheater! Any high scores will not be recorded."));
-                undo_set_sensitive (UndoPossible ());
-        }
-	return FALSE;
-}
-
 /* Define menus later so we don't have to proto callbacks? */
 GnomeUIInfo gamemenu[] = {
         GNOMEUIINFO_MENU_NEW_GAME_ITEM (new_game_callback, NULL),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_MENU_UNDO_MOVE_ITEM (undo_callback, NULL),
-	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_SCORES_ITEM (score_callback, NULL),
 	GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_MENU_QUIT_ITEM (quit_game, NULL),
@@ -546,11 +539,6 @@ GnomeUIInfo mainmenu[] = {
 	GNOMEUIINFO_END
 };
 
-static void undo_set_sensitive (gboolean state)
-{
-        gtk_widget_set_sensitive (gamemenu[2].widget, state);
-}
-
 static void roll_set_sensitive (gboolean state)
 {
 	gtk_widget_set_sensitive (mbutton, state);
@@ -590,12 +578,12 @@ void update_score_state (void)
 	top = gnome_score_get_notable (appID, NULL,
                                        &names, &scores, &scoretimes);
 	if (top > 0) {
-		gtk_widget_set_sensitive (gamemenu[4].widget, TRUE);
+		gtk_widget_set_sensitive (gamemenu[2].widget, TRUE);
 		g_strfreev (names);
 		g_free (scores);
 		g_free (scoretimes);
 	} else {
-		gtk_widget_set_sensitive (gamemenu[4].widget, FALSE);
+		gtk_widget_set_sensitive (gamemenu[2].widget, FALSE);
 	}
 }
 
@@ -606,7 +594,7 @@ GyahtzeeCreateMainWindow(void)
 	GtkWidget *tmp;
 	int i, j;
 
-        gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
+        gtk_window_set_resizable (GTK_WINDOW (window), FALSE); 
         g_signal_connect (G_OBJECT (window), "delete_event",
                           G_CALLBACK (quit_game), NULL);
         g_signal_connect (G_OBJECT (window), "key_press_event",
